summaryrefslogtreecommitdiffstats
path: root/kpdf/ui/pageviewutils.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpdf/ui/pageviewutils.h')
-rw-r--r--kpdf/ui/pageviewutils.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kpdf/ui/pageviewutils.h b/kpdf/ui/pageviewutils.h
index ceac9fe2..68c2f08b 100644
--- a/kpdf/ui/pageviewutils.h
+++ b/kpdf/ui/pageviewutils.h
@@ -23,7 +23,7 @@ class KPDFPage;
/**
* @short PageViewItem represents graphically a kpdfpage into the PageView.
*
* It has methods for settings Item's tqgeometry and other visual properties such
* as the individual zoom factor.
*/
class PageViewItem
@@ -33,7 +33,7 @@ class PageViewItem
const KPDFPage * page() const;
int pageNumber() const;
- const TQRect& tqgeometry() const;
+ const TQRect& geometry() const;
int width() const;
int height() const;
double zoomFactor() const;
@@ -45,7 +45,7 @@ class PageViewItem
private:
const KPDFPage * m_page;
double m_zoomFactor;
- TQRect m_tqgeometry;
+ TQRect m_geometry;
};
@@ -23,7 +23,7 @@ class KPDFPage;
* @short PageViewItem represents graphically a kpdfpage into the PageView.
*
- * It has methods for settings Item's tqgeometry and other visual properties such
+ * It has methods for settings Item's geometry and other visual properties such
* as the individual zoom factor.
*/